@@ -13,7 +13,7 @@ pub fn choose_extractor(url: &str) -> FinaResult<Box<dyn Extractor + 'static>> {
     // todo: deal with unsupported url properly
     match url.domain() {
         Some("bilibili.com" | "www.bilibili.com") => {
-            if url.as_str().contains("av") || url.as_str().contains("bv") {
+            if url.as_str().contains("av") || url.as_str().contains("BV") {
                 Ok(Box::new(bilibili::Video::new(url.as_str())?))
             } else {
                 Ok(Box::new(bilibili::Bangumi::new(url.as_str())?))
